From df644d7f7736fce4e92a75d53f44b3df6671ceeb Mon Sep 17 00:00:00 2001
From: sdzen <sdzen@techie.com>
Date: Wed, 07 Aug 2013 02:08:22 +0200
Subject: [PATCH] Merge pull request #76 from kol0/patch-2

---
 unified_inventory/api.lua |   25 ++++++++++++++++++++++---
 1 files changed, 22 insertions(+), 3 deletions(-)

diff --git a/unified_inventory/api.lua b/unified_inventory/api.lua
index 5ff16fa..c059c87 100644
--- a/unified_inventory/api.lua
+++ b/unified_inventory/api.lua
@@ -22,7 +22,15 @@
 unified_inventory.home_filename = minetest.get_worldpath()..'/unified_inventory_home'
 
 -- Create detached creative inventory after loading all mods
+-- Also 2nd attempt to disable default creative mod
 minetest.after(0.01, function()
+	
+	if creative_inventory then 
+		creative_inventory.set_creative_formspec = function(player, start_i, pagenum)
+		return
+		end
+	end
+
 	unified_inventory.items_list = {}
 	for name,def in pairs(minetest.registered_items) do
 		if (not def.groups.not_in_creative_inventory or def.groups.not_in_creative_inventory == 0)
@@ -230,7 +238,13 @@
 				end	
 				if craft.type == "alloy" then
 				method="Alloy cooking"
-				end	
+				end
+				if craft.type == "extracting" then
+				method="Extracting"
+				end
+				if craft.type == "compressing" then
+				method="Compressing"
+				end		
 				formspec = formspec.."label[6,3;"..method.."]"
 			end
 			
@@ -557,8 +571,13 @@
 	local craft = crafts[alternate]
 	inv:set_stack("output", 1, craft.output)
 	local items=craft.items
-	-- cook, fuel, grinding recipes
-	if craft.type == "cooking" or craft.type == "fuel" or craft.type == "grinding" then
+
+	-- cooking, fuel, grinding, and extracting recipes
+	if craft.type == "cooking" or
+	   craft.type == "fuel" or
+	   craft.type == "grinding" or
+	   craft.type == "extracting" or
+	   craft.type == "compressing" then
 		def=unified_inventory.find_item_def(craft["items"][1])
 		if def then
 			inv:set_stack("build", 1, def)

--
Gitblit v1.8.0